Crate leo_test_framework

Crate leo_test_framework 

This is a simple test framework for the Leo compiler.

Functions

run_single_test
run_tests
Pulls tests from category, running them through the runner and comparing them against expectations in previous runs.